/* $Id$
 *
 * Lasso - A free implementation of the Liberty Alliance specifications.
 *
 * Copyright (C) 2004-2007 Entr'ouvert
 * http://lasso.entrouvert.org
 *
 * Authors: See AUTHORS file in top-level directory.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, see <http://www.gnu.org/licenses/>.
 */

#ifndef __LASSO_XML_WS_H__
#define __LASSO_XML_WS_H__

#include "wsa_attributed_any.h"
#include "wsa_attributed_qname.h"
#include "wsa_attributed_unsigned_long.h"
#include "wsa_attributed_uri.h"
#include "wsa_endpoint_reference.h"
#include "wsa_metadata.h"
#include "wsa_problem_action.h"
#include "wsa_reference_parameters.h"
#include "wsa_relates_to.h"
#include "wsse_embedded.h"
#include "wsse_reference.h"
#include "wsse_security_header.h"
#include "wsse_security_token_reference.h"
#include "wsse_transformation_parameters.h"
#include "wsse_username_token.h"
#include "wsu_timestamp.h"

#endif
